@@ -171,7 +171,7 @@ def job_request( params = { } ) :
     headers = { "X-Omni-Action": "job_request" }
     headers[ "X-Omni-Params" ] = s_util.json_encode( params )
     if( len( headers[ "X-Omni-Params" ] ) > 4096 ) :
-        s_log.write( "ERROR Params TO BIG?? > 4096 bytes... " + str len( headers[ "X-Omni-Params" ] ) )
+        s_log.write( "ERROR Params TO BIG?? > 4096 bytes... " + str( len( headers[ "X-Omni-Params" ] ) ) )
         return( False )
 
 
